---
title: CBR Custom Open Security Summit
---

# cbr-custom-open-sec-summit
Repo for CBR Custom Open Security Summit 


## Repo details

![Current Release](https://img.shields.io/badge/release-v0.1.0-blue)

